@@ -29,7 +29,7 @@ int main()
   In this example we will simulate a rate 1/3 code that is listed in J. G. Proakis,
   "Digital communications". The encoder has constraint length 7.
   */
-  generators.set_size(3,false);
+  generators.set_size(3, false);
   generators(0) = 0133;
   generators(1) = 0145;
   generators(2) = 0175;
@@ -38,38 +38,39 @@ int main()
 
   //Init: Calculate some simulation specific parameters:
   Ec = 1.0;
-  EbN0dB = linspace(-2,6,5);
+  EbN0dB = linspace(-2, 6, 5);
   EbN0 = inv_dB(EbN0dB);
   Eb = Ec / conv_code.get_rate();
-  N0 = Eb * pow(EbN0,-1);
+  N0 = Eb * pow(EbN0, -1);
   MaxNrofErrors = 100;
   Nobits = 10000;
   MaxIterations = 10;
-  ber.set_size(EbN0dB.length(),false);
+  ber.set_size(EbN0dB.length(), false);
   ber.clear();
 
   //Randomize the random number generators.
   RNG_randomize();
 
-  for (p=0; p<EbN0dB.length(); p++) {
+  for (p = 0; p < EbN0dB.length(); p++) {
 
-    cout << "Now simulating point " << p+1 << " out of " << EbN0dB.length() << endl;
+    cout << "Now simulating point " << p + 1 << " out of " << EbN0dB.length() << endl;
     berc.clear();                 //Clear the bit error rate counter.
-    channel.set_noise(N0(p)/2.0); //Set the noise value of the AWGN channel.
+    channel.set_noise(N0(p) / 2.0); //Set the noise value of the AWGN channel.
 
-    for (i=0; i<MaxIterations; i++) {
+    for (i = 0; i < MaxIterations; i++) {
 
       uncoded_bits = randb(Nobits);                   //The uncoded bits.
       coded_bits = conv_code.encode(uncoded_bits);    //The convolutional encoder function.
       bpsk.modulate_bits(coded_bits, trans_symbols); //The BPSK modulator.
-      rec_symbols = channel( trans_symbols );         //The AWGN channel.
+      rec_symbols = channel(trans_symbols);           //The AWGN channel.
       decoded_bits = conv_code.decode(rec_symbols);   //The Viterbi decoder function.
-      berc.count(uncoded_bits,decoded_bits);          //Count the errors.
+      berc.count(uncoded_bits, decoded_bits);         //Count the errors.
       ber(p) = berc.get_errorrate();
 
       //Break the simulation on this point if sufficient number of bit errors were observed:
-      if (berc.get_errors()>MaxNrofErrors) {
-	cout << "Breaking on point " << p+1 << " with " << berc.get_errors() << " errors." << endl; break;
+      if (berc.get_errors() > MaxNrofErrors) {
+        cout << "Breaking on point " << p + 1 << " with " << berc.get_errors() << " errors." << endl;
+        break;
       }
 
     }
